AnnotatedDropSliderValueIndicatorShape constructor
const
AnnotatedDropSliderValueIndicatorShape()
Create a slider value indicator that resembles a drop shape.
Implementation
const AnnotatedDropSliderValueIndicatorShape();
Create a slider value indicator that resembles a drop shape.
const AnnotatedDropSliderValueIndicatorShape();