AnnotatedGappedSliderTrackShape constructor
const
AnnotatedGappedSliderTrackShape()
Create a slider track that draws two rectangles with rounded outer edges.
Implementation
const AnnotatedGappedSliderTrackShape();
Create a slider track that draws two rectangles with rounded outer edges.
const AnnotatedGappedSliderTrackShape();