AnnotatedHandleThumbShape class
The bar shape of a Slider's thumb.
When the slider is enabled, the ColorScheme.primary color is used for the thumb. When the slider is disabled, the ColorScheme.onSurface color with an opacity of 0.38 is used for the thumb.
The thumb bar shape width is reduced when the thumb is pressed.
If SliderThemeData.thumbSize is null, then the thumb size is 4 pixels for the width and 44 pixels for the height.
This is the default thumb shape for Slider. If ThemeData.useMaterial3 is false, then the default thumb shape is RoundSliderThumbShape.
See also:
- Slider, which includes an overlay defined by this shape.
- SliderTheme, which can be used to configure the overlay shape of all sliders in a widget subtree.
- Inheritance
-
- Object
- AnnotatedSliderComponentShape
- AnnotatedHandleThumbShape
Constructors
- AnnotatedHandleThumbShape()
-
Create a slider thumb that draws a bar.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getPreferredSize(
bool isEnabled, bool isDiscrete) → Size -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
paint(
PaintingContext context, Offset center, {required Animation< double> activationAnimation, required Animation<double> enableAnimation, required bool isDiscrete, required TextPainter labelPainter, required RenderBox parentBox, required AnnotatedSliderThemeData sliderTheme, required TextDirection textDirection, required double value, required double textScaleFactor, required Size sizeWithOverflow}) → void -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited