AnnotatedRangeSliderThumbShape class
abstract
Constructors
-
AnnotatedRangeSliderThumbShape()
-
This abstract const constructor enables subclasses to provide
const constructors so that they can be used in const expressions.
const
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getPreferredSize(bool isEnabled, bool isDiscrete)
→ Size
-
Returns the preferred size of the shape, based on the given conditions.
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
paint(PaintingContext context, Offset center, {required Animation<double> activationAnimation, required Animation<double> enableAnimation, bool isDiscrete, bool isEnabled, bool isOnTop, TextDirection textDirection, required SliderThemeData sliderTheme, Thumb thumb, bool isPressed})
→ void
-
Paints the thumb shape based on the state passed to it.
-
toString()
→ String
-
A string representation of this object.
inherited