AnnotatedRangeSliderTickMarkShape class abstract

Implementers

Constructors

AnnotatedRangeSliderTickMarkShape()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getPreferredSize({required AnnotatedSliderThemeData sliderTheme, bool isEnabled}) Size
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paint(PaintingContext context, Offset center, {required RenderBox parentBox, required AnnotatedSliderThemeData sliderTheme, required Animation<double> enableAnimation, required Offset startThumbCenter, required Offset endThumbCenter, bool isEnabled, required TextDirection textDirection}) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited