AnnotatedRangeSliderTrackShape class abstract

Implementers

Constructors

AnnotatedRangeSliderTrackShape()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
isRounded bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getPreferredRect({required RenderBox parentBox, Offset offset = Offset.zero, required AnnotatedSliderThemeData sliderTheme, bool isEnabled, bool isDiscrete}) Rect
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paint(PaintingContext context, Offset offset, {required RenderBox parentBox, required AnnotatedSliderThemeData sliderTheme, required Animation<double> enableAnimation, required Offset startThumbCenter, required Offset endThumbCenter, bool isEnabled = false, bool isDiscrete = false, required TextDirection textDirection}) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited