AnnotatedRangeSliderValueIndicatorShape class
abstract
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getHorizontalShift({RenderBox? parentBox, Offset? center, TextPainter? labelPainter, Animation<double>? activationAnimation, double? textScaleFactor, Size? sizeWithOverflow})
→ double
-
Determines the best offset to keep this shape on the screen.
-
getPreferredSize(bool isEnabled, bool isDiscrete, {required TextPainter labelPainter, required double textScaleFactor})
→ Size
-
Returns the preferred size of the shape, based on the given conditions.
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
paint(PaintingContext context, Offset center, {required Animation<double> activationAnimation, required Animation<double> enableAnimation, bool isDiscrete, bool isOnTop, required TextPainter labelPainter, double textScaleFactor, Size sizeWithOverflow, required RenderBox parentBox, required SliderThemeData sliderTheme, TextDirection textDirection, double value, Thumb thumb})
→ void
-
Paints the value indicator shape based on the state passed to it.
-
toString()
→ String
-
A string representation of this object.
inherited