AnnotatedRectangularRangeSliderTrackShape constructor
const
AnnotatedRectangularRangeSliderTrackShape()
Create a slider track with rectangular outer edges.
The middle track segment is the selected range and is active, and the two outer track segments are inactive.
Implementation
const AnnotatedRectangularRangeSliderTrackShape();