AnnotatedRoundedRectRangeSliderTrackShape constructor
const
AnnotatedRoundedRectRangeSliderTrackShape()
Create a slider track with rounded outer edges.
The middle track segment is the selected range and is active, and the two outer track segments are inactive.
Implementation
const AnnotatedRoundedRectRangeSliderTrackShape();