AnnotatedSliderMarkerShape class
abstract
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
isRounded
→ bool
-
no setter
-
markerValue
→ List<double>
-
If your shape is based on value positioning (0.0 to 1.0),
override this to return a custom value.
Default: -1 (invalid).
no setter
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getPreferredRect({required RenderBox parentBox, Offset offset = Offset.zero, required AnnotatedSliderThemeData sliderTheme, bool isEnabled, bool isDiscrete})
→ List<Rect>
-
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
paint(PaintingContext context, Offset offset, {required RenderBox parentBox, required AnnotatedSliderThemeData sliderTheme, required Animation<double> enableAnimation, required Offset thumbCenter, Offset? secondaryOffset, required bool isEnabled, required bool isDiscrete, required TextDirection textDirection})
→ void
-
-
toString()
→ String
-
A string representation of this object.
inherited