AnnotatedSliderThemeData class
- Mixed-in types
- Annotations
Constructors
-
AnnotatedSliderThemeData({double? trackHeight, Color? activeTrackColor, Color? inactiveTrackColor, Color? secondaryActiveTrackColor, Color? disabledActiveTrackColor, Color? disabledInactiveTrackColor, Color? disabledSecondaryActiveTrackColor, Color? activeTickMarkColor, Color? inactiveTickMarkColor, Color? disabledActiveTickMarkColor, Color? disabledInactiveTickMarkColor, Color? thumbColor, Color? overlappingShapeStrokeColor, Color? disabledThumbColor, Color? overlayColor, Color? valueIndicatorColor, Color? valueIndicatorStrokeColor, AnnotatedSliderComponentShape? overlayShape, AnnotatedSliderTickMarkShape? tickMarkShape, AnnotatedSliderComponentShape? thumbShape, AnnotatedSliderTrackShape? trackShape, AnnotatedSliderComponentShape? valueIndicatorShape, AnnotatedRangeSliderTickMarkShape? rangeTickMarkShape, AnnotatedRangeSliderThumbShape? rangeThumbShape, AnnotatedRangeSliderTrackShape? rangeTrackShape, AnnotatedRangeSliderValueIndicatorShape? rangeValueIndicatorShape, ShowValueIndicator? showValueIndicator, TextStyle? valueIndicatorTextStyle, double? minThumbSeparation, RangeThumbSelector? thumbSelector, WidgetStateProperty<
MouseCursor?> ? mouseCursor, SliderInteraction? allowedInteraction, EdgeInsetsGeometry? padding, WidgetStateProperty<Size?> ? thumbSize, double? trackGap, TextStyle? markerLabelTextStyle, AnnotatedSliderMarkerShape? markerShape, @Deprecated('Use SliderTheme to customize the Slider appearance. ' 'This feature was deprecated after v3.27.0-0.2.pre.') bool? year2023}) -
const
- AnnotatedSliderThemeData.fallback()
-
factory
- AnnotatedSliderThemeData.fromPrimaryColors({required Color primaryColor, required Color primaryColorDark, required Color primaryColorLight, required TextStyle valueIndicatorTextStyle, required TextStyle markerLabelTextStyle})
-
Generates a SliderThemeData from three main colors.
factory
Properties
- activeTickMarkColor → Color?
-
The color of the track's tick marks that are drawn between the Slider.min
position and the current thumb position.
final
- activeTrackColor → Color?
-
The color of the Slider track between the Slider.min position and the
current thumb position.
final
- allowedInteraction → SliderInteraction?
-
Allowed way for the user to interact with the Slider.
final
- disabledActiveTickMarkColor → Color?
-
The color of the track's tick marks that are drawn between the Slider.min
position and the current thumb position when the Slider is disabled.
final
- disabledActiveTrackColor → Color?
-
The color of the Slider track between the Slider.min position and the
current thumb position when the Slider is disabled.
final
- disabledInactiveTickMarkColor → Color?
-
The color of the track's tick marks that are drawn between the current
thumb position and the Slider.max position when the Slider is
disabled.
final
- disabledInactiveTrackColor → Color?
-
The color of the Slider track between the current thumb position and the
Slider.max position when the Slider is disabled.
final
- disabledSecondaryActiveTrackColor → Color?
-
The color of the Slider track between the current thumb position and the
Slider.secondaryTrackValue position when the Slider is disabled.
final
- disabledThumbColor → Color?
-
The color given to the thumbShape to draw itself with when the
Slider is disabled.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- inactiveTickMarkColor → Color?
-
The color of the track's tick marks that are drawn between the current
thumb position and the Slider.max position.
final
- inactiveTrackColor → Color?
-
The color of the Slider track between the current thumb position and the
Slider.max position.
final
- markerLabelTextStyle → TextStyle?
-
final
- markerShape → AnnotatedSliderMarkerShape?
-
final
- minThumbSeparation → double?
-
Limits the thumb's separation distance.
final
-
mouseCursor
→ WidgetStateProperty<
MouseCursor?> ? -
The cursor for a mouse pointer when it enters or is hovering over the
widget.
final
- overlappingShapeStrokeColor → Color?
-
The color given to the perimeter of the top rangeThumbShape when the
thumbs are overlapping and the top rangeValueIndicatorShape when the
value indicators are overlapping.
final
- overlayColor → Color?
-
The color of the overlay drawn around the slider thumb when it is
pressed, focused, or hovered.
final
- overlayShape → AnnotatedSliderComponentShape?
-
The shape that will be used to draw the Slider's overlay.
final
- padding → EdgeInsetsGeometry?
-
Determines the padding around the Slider.
final
- rangeThumbShape → AnnotatedRangeSliderThumbShape?
-
The shape that will be used for the RangeSlider's thumbs.
final
- rangeTickMarkShape → AnnotatedRangeSliderTickMarkShape?
-
The shape that will be used to draw the RangeSlider's tick marks.
final
- rangeTrackShape → AnnotatedRangeSliderTrackShape?
-
The shape that will be used to draw the RangeSlider's track.
final
- rangeValueIndicatorShape → AnnotatedRangeSliderValueIndicatorShape?
-
The shape that will be used for the RangeSlider's value indicators.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- secondaryActiveTrackColor → Color?
-
The color of the Slider track between the current thumb position and the
Slider.secondaryTrackValue position.
final
- showValueIndicator → ShowValueIndicator?
-
Whether the value indicator should be shown for different types of
sliders.
final
- thumbColor → Color?
-
The color given to the thumbShape to draw itself with.
final
- thumbSelector → RangeThumbSelector?
-
Determines which thumb should be selected when the slider is interacted
with.
final
- thumbShape → AnnotatedSliderComponentShape?
-
The shape that will be used to draw the Slider's thumb.
final
-
thumbSize
→ WidgetStateProperty<
Size?> ? -
The size of the HandleThumbShape thumb.
final
- tickMarkShape → AnnotatedSliderTickMarkShape?
-
The shape that will be used to draw the Slider's tick marks.
final
- trackGap → double?
-
The size of the gap between the active and inactive tracks of the GappedSliderTrackShape.
final
- trackHeight → double?
-
The height of the Slider track.
final
- trackShape → AnnotatedSliderTrackShape?
-
The shape that will be used to draw the Slider's track.
final
- valueIndicatorColor → Color?
-
The color given to the valueIndicatorShape to draw itself with.
final
- valueIndicatorShape → AnnotatedSliderComponentShape?
-
The shape that will be used to draw the Slider's value
indicator.
final
- valueIndicatorStrokeColor → Color?
-
The color given to the valueIndicatorShape stroke.
final
- valueIndicatorTextStyle → TextStyle?
-
The text style for the text on the value indicator.
final
- year2023 → bool?
-
Overrides the default value of Slider.year2023.
final
Methods
-
copyWith(
{double? trackHeight, Color? activeTrackColor, Color? inactiveTrackColor, Color? secondaryActiveTrackColor, Color? disabledActiveTrackColor, Color? disabledInactiveTrackColor, Color? disabledSecondaryActiveTrackColor, Color? activeTickMarkColor, Color? inactiveTickMarkColor, Color? disabledActiveTickMarkColor, Color? disabledInactiveTickMarkColor, Color? thumbColor, Color? overlappingShapeStrokeColor, Color? disabledThumbColor, Color? overlayColor, Color? valueIndicatorColor, Color? valueIndicatorStrokeColor, AnnotatedSliderComponentShape? overlayShape, AnnotatedSliderTickMarkShape? tickMarkShape, AnnotatedSliderComponentShape? thumbShape, AnnotatedSliderTrackShape? trackShape, AnnotatedSliderComponentShape? valueIndicatorShape, AnnotatedRangeSliderTickMarkShape? rangeTickMarkShape, AnnotatedRangeSliderThumbShape? rangeThumbShape, AnnotatedRangeSliderTrackShape? rangeTrackShape, AnnotatedRangeSliderValueIndicatorShape? rangeValueIndicatorShape, AnnotatedSliderMarkerShape? markerShape, ShowValueIndicator? showValueIndicator, TextStyle? valueIndicatorTextStyle, TextStyle? markerLabelTextStyle, double? minThumbSeparation, RangeThumbSelector? thumbSelector, WidgetStateProperty< MouseCursor?> ? mouseCursor, SliderInteraction? allowedInteraction, EdgeInsetsGeometry? padding, WidgetStateProperty<Size?> ? thumbSize, double? trackGap, bool? year2023}) → AnnotatedSliderThemeData - Creates a copy of this object but with the given fields replaced with the new values.
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringShort(
) → String -
A brief description of this object, usually just the runtimeType and the
hashCode.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
lerp(
AnnotatedSliderThemeData a, AnnotatedSliderThemeData b, double t) → AnnotatedSliderThemeData - Linearly interpolate between two slider themes.