disabledActiveTickMarkColor property
The color of the track's tick marks that are drawn between the Slider.min position and the current thumb position when the Slider is disabled.
Implementation
final Color? disabledActiveTickMarkColor;
The color of the track's tick marks that are drawn between the Slider.min position and the current thumb position when the Slider is disabled.
final Color? disabledActiveTickMarkColor;