disabledInactiveTickMarkColor property
The color of the track's tick marks that are drawn between the current thumb position and the Slider.max position when the Slider is disabled.
Implementation
final Color? disabledInactiveTickMarkColor;
The color of the track's tick marks that are drawn between the current thumb position and the Slider.max position when the Slider is disabled.
final Color? disabledInactiveTickMarkColor;