AnnotatedSliderTrackShape constructor

const AnnotatedSliderTrackShape()

This abstract const constructor enables subclasses to provide const constructors so that they can be used in const expressions.

Implementation

const AnnotatedSliderTrackShape();