isRounded property
bool
get
isRounded
Whether the track shape is rounded.
This is used to determine the correct position of the thumb in relation to the track.
Implementation
bool get isRounded => false;
Whether the track shape is rounded.
This is used to determine the correct position of the thumb in relation to the track.
bool get isRounded => false;