RangeThumbSelector typedef

RangeThumbSelector = Thumb? Function(TextDirection textDirection, RangeValues values, double tapValue, Size thumbSize, Size trackSize, double dx)

A callback that formats a numeric value from a Slider or RangeSlider widget.

See also:

The default finds the closest thumb, but if the thumbs are close to each other, it waits for movement defined by dx to determine the selected thumb.

Override SliderThemeData.thumbSelector for custom thumb selection.

Implementation

/// Decides which thumbs (if any) should be selected.
///
/// The default finds the closest thumb, but if the thumbs are close to each
/// other, it waits for movement defined by [dx] to determine the selected
/// thumb.
///
/// Override [SliderThemeData.thumbSelector] for custom thumb selection.
typedef RangeThumbSelector =
    Thumb? Function(
      TextDirection textDirection,
      RangeValues values,
      double tapValue,
      Size thumbSize,
      Size trackSize,
      double dx,
    );