annotated_slider_theme library
Classes
- AnnotatedDropSliderValueIndicatorShape
- The default shape of a Material 3 Slider's value indicator.
- AnnotatedGappedSliderTrackShape
- The gapped shape of a Slider's track.
- AnnotatedHandleThumbShape
- The bar shape of a Slider's thumb.
- AnnotatedPaddleRangeSliderValueIndicatorShape
- A variant shape of a RangeSlider's value indicators. The value indicator is in the shape of an upside-down pear.
- AnnotatedPaddleSliderValueIndicatorShape
- A variant shape of a Slider's value indicator . The value indicator is in the shape of an upside-down pear.
- AnnotatedRangeSliderThumbShape
- AnnotatedRangeSliderTickMarkShape
- AnnotatedRangeSliderTrackShape
- AnnotatedRangeSliderValueIndicatorShape
- AnnotatedRectangularRangeSliderTrackShape
- A RangeSlider track that's a simple rectangle.
- AnnotatedRectangularSliderTrackShape
- AnnotatedRectangularSliderValueIndicatorShape
- The default shape of a Slider's value indicator.
- AnnotatedRoundedRectRangeSliderTrackShape
- The default shape of a RangeSlider's track.
- AnnotatedRoundedRectSliderTrackShape
- AnnotatedRoundedRectSliderValueIndicatorShape
- The rounded rectangle shape of a Slider's value indicator.
- AnnotatedRoundRangeSliderThumbShape
- The default shape of a RangeSlider's thumbs.
- AnnotatedRoundRangeSliderTickMarkShape
- The default shape of each RangeSlider tick mark.
- AnnotatedRoundSliderOverlayShape
- The default shape of a Slider's thumb overlay.
- AnnotatedRoundSliderThumbShape
- The default shape of a Slider's thumb.
- AnnotatedRoundSliderTickMarkShape
- The default shape of each Slider tick mark.
- AnnotatedSliderComponentShape
- Base class for slider thumb, thumb overlay, and value indicator shapes.
- AnnotatedSliderMarkerShape
- AnnotatedSliderTheme
- AnnotatedSliderThemeData
- AnnotatedSliderTickMarkShape
- Base class for Slider tick mark shapes.
- AnnotatedSliderTrackShape
- Base class for slider track shapes.
- RangeLabels
- Object for setting range slider label values that appear in the value indicator for each thumb.
- RangeValues
- Object for representing range slider thumb values.
- RectangularRangeSliderValueIndicatorShape
- The default shape of a RangeSlider's value indicators.
Mixins
- AnnotatedBaseRangeSliderTrackShape
- Base range slider track shape that provides an implementation of getPreferredRect for default sizing.
- AnnotatedBaseSliderTrackShape
Typedefs
- RangeThumbSelector = Thumb? Function(TextDirection textDirection, RangeValues values, double tapValue, Size thumbSize, Size trackSize, double dx)
- A callback that formats a numeric value from a Slider or RangeSlider widget.